Constraint Helpers
==================

Functions for building common constraint patterns.

Cardinality Constraints
-----------------------

.. autofunction:: cvxpy_or.at_most_k

.. autofunction:: cvxpy_or.exactly_k

.. autofunction:: cvxpy_or.at_least_k

Logical Constraints
-------------------

.. autofunction:: cvxpy_or.implies

.. autofunction:: cvxpy_or.mutex

.. autofunction:: cvxpy_or.one_of

Bound Constraints
-----------------

.. autofunction:: cvxpy_or.bounds

Flow Constraints
----------------

.. autofunction:: cvxpy_or.flow_balance
